{% extends "granadilla/device_base.html" %}
{% load i18n %}

{% block content %}

{% if object %} 

<h1>{% blocktrans %} Generated password for {{ object }}{% endblocktrans %}</h1>
{% trans "The device's password will be: " %} {{ object.tmppwd }}

<form method="POST">
{% csrf_token %}
<input type="submit" value="{% trans "Back" %}" />
</form>

{% else %}
<p>{% trans "This device does not exist." %}</p>
<a href="{% url "granadilla.views.device_list" %}">{% trans "Back to the device list" %}</a>

{% endif %}

{% endblock %}
